@@ -1,6 +1,7 @@
 class RuCaptchaError(Exception):
     """Базовый класс для всех исключений в этом модуле."""
-    def errors(self, description):
+    @staticmethod
+    def errors(description):
         """
         Ошибки in.php
         """
@@ -30,7 +31,7 @@ class RuCaptchaError(Exception):
             return BannedIPError.answer()
         elif description == 'ERROR_BAD_TOKEN_OR_PAGEURL':
             return BadTokenOrPageurlCaptchaError.answer()
-        elif description == 'ERROR_GOOGLEKEY':
+        elif description in ('ERROR_GOOGLEKEY', 'ERROR_WRONG_GOOGLEKEY'):
             return ErrorGoogleKeyCaptchaError.answer()
         elif description == 'ERROR_CAPTCHAIMAGE_BLOCKED':
             return BlockedimageCaptchaError.answer()
@@ -63,12 +64,28 @@ class RuCaptchaError(Exception):
         elif description == 'ERROR: 1005':
             return Number1005Error.answer()
 
+        # Error: New/Unknown
+        else:
+            return UnknownError.answer(description=description)
+
 
 class ReadError(Exception):
     def __init__(self, error):
         Exception.__init__(self, f"\n\tОшибка порождается при невозможности открыть переднный файл!\n\t\t{error}")
 
 
+class UnknownError(RuCaptchaError):
+    @staticmethod
+    def answer(description: str):
+        return {'text': f"""Исключение порождается при неправильном неизвестной ошибке.
+                            Сообщите о данной ошибке разработчикам библиотеки - мы её обязательно добавим в список с описанием.
+                        
+                            {description} - исключение.
+                            """,
+                'id': -1
+                }
+
+
 class WrongUserKeyError(RuCaptchaError):
     @staticmethod
     def answer():
@@ -236,19 +253,15 @@ class BadTokenOrPageurlCaptchaError(RuCaptchaError):
 class ErrorGoogleKeyCaptchaError(RuCaptchaError):
     @staticmethod
     def answer():
-        return {'text': """Исключение порождается при несуществующем RuCaptcha KEY.
-                            Ключ, который вы указали не существует.
-                            Прекратите отправку запросов и проверьте ваш ключ API.
-                
-                            ERROR_KEY_DOES_NOT_EXIST - исключение из таблицы.""",
+        return {'text':     """Исключение порождается при некорректном recaptcha-sitekey.
+                                Вы можете получить эту ошибку, если отправляете нам ReCaptcha V2. Ошибка возвращается если sitekey в вашем запросе
+                                пустой или имеет некорректный формат.
+
+                                ERROR_GOOGLEKEY - искючение из таблицы.
+                                """,
                 'id': 23
                 }
-    """Исключение порождается при некорректном recaptcha-sitekey.
-    Вы можете получить эту ошибку, если отправляете нам ReCaptcha V2. Ошибка возвращается если sitekey в вашем запросе
-    пустой или имеет некорректный формат.
 
-    ERROR_GOOGLEKEY - искючение из таблицы.
-    """
 
 
 class BlockedimageCaptchaError(RuCaptchaError):
